@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
 
-def determineStartEnd(sequence, mingap_perc=0.05, redefine_perc=0.1):
+def determineStartEnd(sequence, name, log, mingap_perc=0.05, redefine_perc=0.1):
     '''
     Determines the start and the end of a sequence by calling a subroutine
 
@@ -10,6 +10,12 @@ def determineStartEnd(sequence, mingap_perc=0.05, redefine_perc=0.1):
     sequence: np.array
         sequence
 
+    name: string
+        name of the sequence
+
+    log: logging.Logger
+        An open log file object
+
     mingap_perc: float
         proportion of the sequence length (excluding gaps) that is the
         threshold for change in gap numbers within the first 10% of non-gap
@@ -33,7 +39,15 @@ def determineStartEnd(sequence, mingap_perc=0.05, redefine_perc=0.1):
 
     start = 0
     end = 0
-    start = findValue(sequence, mingap_perc)
+    gaps = countGaps(sequence)
+    # make sure the mingap is not lower than 2, and if it is give a warning
+    mingap = int(mingap_perc*len(gaps))
+    # print("mingap:", mingap)
+    if mingap < 2 and len(gaps) > 20:
+        log.warning("Given the length of sequence %s, the mingap_perc threshold is too low and the change in gap numbers was replaced by 2." % name)
+        print("Given the length of sequence %s, the mingap_perc threshold is too low and the change in gap numbers was replaced by 2.\n" % name)
+
+    start = findValue(sequence, mingap_perc, redefine_perc)
     # put in reverse for end
     end = len(sequence) - findValue(sequence[::-1], mingap_perc, redefine_perc)
 
@@ -51,6 +65,12 @@ def findValue(sequence, mingap_perc=0.05, redefine_perc=0.1):
     sequence: numpy array
         sequence
 
+    name: string
+        name of the sequence
+
+    log: logging.Logger
+        An open log file object
+
     mingap_perc: float
         proportion of the sequence length (excluding gaps) that is the
         threshold for change in gap numbers within the first checkfor_perc %
@@ -79,6 +99,9 @@ def findValue(sequence, mingap_perc=0.05, redefine_perc=0.1):
     boundary3 = int(0.01*seq_length)
     # the threshold for the change in gap numbers
     mingap = int(mingap_perc*seq_length)
+    # make sure mingap is not lower than 2 and if it is, set it to 2
+    if mingap < 2:
+        mingap = 2
 
     # for very short sequences it is not desirable to redefine
     if seq_length < 21:
